sequencetools.Matrix
====================

.. abjad-lineage:: abjad.tools.sequencetools.Matrix.Matrix.Matrix

.. autoclass:: abjad.tools.sequencetools.Matrix.Matrix.Matrix
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.sequencetools.Matrix.Matrix.Matrix.columns
   :noindex:

.. autoattribute:: abjad.tools.sequencetools.Matrix.Matrix.Matrix.rows
   :noindex:

.. autoattribute:: abjad.tools.sequencetools.Matrix.Matrix.Matrix.storage_format
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.sequencetools.Matrix.Matrix.Matrix.__eq__
   :noindex:

.. automethod:: abjad.tools.sequencetools.Matrix.Matrix.Matrix.__ge__
   :noindex:

.. automethod:: abjad.tools.sequencetools.Matrix.Matrix.Matrix.__getitem__
   :noindex:

.. automethod:: abjad.tools.sequencetools.Matrix.Matrix.Matrix.__gt__
   :noindex:

.. automethod:: abjad.tools.sequencetools.Matrix.Matrix.Matrix.__le__
   :noindex:

.. automethod:: abjad.tools.sequencetools.Matrix.Matrix.Matrix.__lt__
   :noindex:

.. automethod:: abjad.tools.sequencetools.Matrix.Matrix.Matrix.__ne__
   :noindex:

.. automethod:: abjad.tools.sequencetools.Matrix.Matrix.Matrix.__repr__
   :noindex:
